pub fn create_time_channels() -> (TimeSender, TimeReceiver)Available on crate feature
std only.Expand description
Creates channels used for sending time between the render world and the main world.
pub fn create_time_channels() -> (TimeSender, TimeReceiver)std only.Creates channels used for sending time between the render world and the main world.